aboutsummaryrefslogtreecommitdiff
path: root/libgo/go/html/token.go
diff options
context:
space:
mode:
Diffstat (limited to 'libgo/go/html/token.go')
-rw-r--r--libgo/go/html/token.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/libgo/go/html/token.go b/libgo/go/html/token.go
index c5b8a1c..2c13822 100644
--- a/libgo/go/html/token.go
+++ b/libgo/go/html/token.go
@@ -123,7 +123,7 @@ type Tokenizer struct {
// for tt != Error && err != nil to hold: this means that Next returned a
// valid token but the subsequent Next call will return an error token.
// For example, if the HTML text input was just "plain", then the first
- // Next call would set z.err to os.EOF but return a TextToken, and all
+ // Next call would set z.err to io.EOF but return a TextToken, and all
// subsequent Next calls would return an ErrorToken.
// err is never reset. Once it becomes non-nil, it stays non-nil.
err error
@@ -149,9 +149,9 @@ type Tokenizer struct {
textIsRaw bool
}
-// Error returns the error associated with the most recent ErrorToken token.
-// This is typically os.EOF, meaning the end of tokenization.
-func (z *Tokenizer) Error() error {
+// Err returns the error associated with the most recent ErrorToken token.
+// This is typically io.EOF, meaning the end of tokenization.
+func (z *Tokenizer) Err() error {
if z.tt != ErrorToken {
return nil
}